"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Activity = void 0;
const entity_base_1 = require("../../common/entity.base");
const actor_entity_1 = require("./actor.entity");
const article_object_1 = require("./article.object");
const uri_object_1 = require("./uri.object");
function getURI(input) {
    if (input instanceof uri_object_1.URI) {
        return input;
    }
    if (typeof input === 'string') {
        return new uri_object_1.URI(input);
    }
    if (typeof input !== 'object' || input === null) {
        throw new Error(`Could not create URI from ${JSON.stringify(input)}`);
    }
    if ('id' in input && typeof input.id === 'string') {
        return new uri_object_1.URI(input.id);
    }
    throw new Error(`Could not create URI from ${JSON.stringify(input)}`);
}
function checkKeys(keys, obj) {
    for (const key of keys) {
        if (!(key in obj)) {
            throw new Error(`Missing key ${key}`);
        }
    }
    return obj;
}
class Activity extends entity_base_1.Entity {
    get type() {
        return this.attr.type;
    }
    getObject(url) {
        if (this.attr.object instanceof article_object_1.Article) {
            return this.attr.object.getJSONLD(url);
        }
        return this.attr.object;
    }
    getActor(url) {
        if (this.attr.actor instanceof actor_entity_1.Actor) {
            return this.attr.actor.getJSONLD(url);
        }
        return this.attr.actor;
    }
    get actorId() {
        if (this.attr.actor instanceof actor_entity_1.Actor) {
            return this.attr.actor.actorId;
        }
        return this.attr.actor.id;
    }
    get objectId() {
        if (this.attr.object instanceof article_object_1.Article) {
            return this.attr.object.objectId;
        }
        return this.attr.object.id;
    }
    get activityId() {
        return this.attr.activity;
    }
    getJSONLD(url) {
        const object = this.getObject(url);
        const actor = this.getActor(url);
        return {
            '@context': 'https://www.w3.org/ns/activitystreams',
            id: this.activityId?.getValue(url) || null,
            type: this.attr.type,
            actor: {
                ...actor,
                id: this.actorId.getValue(url)
            },
            object: {
                ...object,
                id: this.objectId.getValue(url)
            },
            to: this.attr.to?.getValue(url) || null
        };
    }
    static fromJSONLD(json) {
        const parsed = checkKeys(['type', 'actor', 'object'], json);
        if (typeof parsed.type !== 'string' || !['Create', 'Follow', 'Accept'].includes(parsed.type)) {
            throw new Error(`Unknown type ${parsed.type}`);
        }
        return new Activity({
            activity: 'id' in json && typeof json.id === 'string' ? getURI(json.id) : null,
            type: parsed.type,
            actor: {
                // eslint-disable-next-line @typescript-eslint/no-explicit-any
                ...parsed.actor,
                id: getURI(parsed.actor)
            },
            object: {
                // eslint-disable-next-line @typescript-eslint/no-explicit-any
                ...parsed.object,
                id: getURI(parsed.object)
            },
            to: 'to' in json ? getURI(json.to) : null
        });
    }
}
exports.Activity = Activity;
//# sourceMappingURL=activity.entity.js.map