"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = __importDefault(require("assert"));
const activity_entity_1 = require("./activity.entity");
const uri_object_1 = require("./uri.object");
const article_object_1 = require("./article.object");
const bson_objectid_1 = __importDefault(require("bson-objectid"));
const actor_entity_1 = require("./actor.entity");
describe('Activity', function () {
    describe('fromJSONLD', function () {
        it('Can construct an entity from JSONLD with various id types', async function () {
            const input = {
                id: new uri_object_1.URI('https://site.com/activity'),
                type: 'Follow',
                actor: {
                    id: 'https://site.com/actor'
                },
                object: 'https://site.com/object'
            };
            const activity = activity_entity_1.Activity.fromJSONLD(input);
            (0, assert_1.default)(activity);
        });
        it('Will throw for unknown types', async function () {
            const input = {
                id: new uri_object_1.URI('https://site.com/activity'),
                type: 'Unknown',
                actor: {
                    id: 'https://site.com/actor'
                },
                object: 'https://site.com/object'
            };
            assert_1.default.throws(() => {
                activity_entity_1.Activity.fromJSONLD(input);
            });
        });
        it('Will throw for missing actor,object or type', async function () {
            const input = {
                id: new uri_object_1.URI('https://site.com/activity'),
                type: 'Unknown',
                actor: {
                    id: 'https://site.com/actor'
                },
                object: 'https://site.com/object'
            };
            for (const prop of ['actor', 'object', 'type']) {
                const modifiedInput = Object.create(input);
                delete modifiedInput[prop];
                assert_1.default.throws(() => {
                    activity_entity_1.Activity.fromJSONLD(modifiedInput);
                });
            }
        });
        it('Can correctly reconstruct', function () {
            const actor = actor_entity_1.Actor.create({ username: 'testing' });
            const article = article_object_1.Article.fromPost({
                id: new bson_objectid_1.default(),
                title: 'My Title',
                slug: 'my-title',
                html: '<p> big boi contents </p>',
                excerpt: 'lil contents',
                authors: ['Jeremy Paxman'],
                url: new uri_object_1.URI('blah'),
                publishedAt: new Date(),
                featuredImage: null,
                visibility: 'public'
            });
            const activity = new activity_entity_1.Activity({
                type: 'Create',
                activity: null,
                actor: actor,
                object: article,
                to: new uri_object_1.URI('bloo')
            });
            const baseUrl = new URL('https://ghost.org');
            const input = activity.getJSONLD(baseUrl);
            const created = activity_entity_1.Activity.fromJSONLD(input);
            assert_1.default.deepEqual(created.getJSONLD(baseUrl), input);
        });
    });
});
//# sourceMappingURL=activity.entity.test.js.map