"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = __importDefault(require("assert"));
const activitypub_service_1 = require("./activitypub.service");
const actor_entity_1 = require("./actor.entity");
const sinon_1 = __importDefault(require("sinon"));
const uri_object_1 = require("./uri.object");
describe('ActivityPubService', function () {
    describe('#follow', function () {
        it('Throws if it cannot find the default actor', async function () {
            const mockWebFingerService = {
                async finger() {
                    return {};
                }
            };
            const mockActorRepository = {
                async getOne() {
                    return null;
                }
            };
            const service = new activitypub_service_1.ActivityPubService(mockWebFingerService, mockActorRepository);
            await assert_1.default.rejects(async () => {
                await service.follow('@egg@ghost.org');
            }, /Could not find default actor/);
        });
        it('Follows the actor and saves', async function () {
            const mockWebFingerService = {
                finger: sinon_1.default.stub().resolves({
                    id: 'https://example.com/user-to-follow'
                })
            };
            const actor = actor_entity_1.Actor.create({ username: 'testing' });
            const mockActorRepository = {
                getOne: sinon_1.default.stub().resolves(actor),
                save: sinon_1.default.stub().resolves()
            };
            const service = new activitypub_service_1.ActivityPubService(mockWebFingerService, mockActorRepository);
            const followStub = sinon_1.default.stub(actor, 'follow');
            await service.follow('@egg@ghost.org');
            (0, assert_1.default)(followStub.calledWithMatch({
                id: new uri_object_1.URI('https://example.com/user-to-follow'),
                username: '@egg@ghost.org'
            }));
            (0, assert_1.default)(mockActorRepository.save.calledWith(actor));
        });
    });
});
//# sourceMappingURL=activitypub.service.test.js.map