/// <reference types="node" />
/// <reference types="node" />
import ObjectID from 'bson-objectid';
import { Entity } from '../../common/entity.base';
import { ActivityPub } from './types';
import { Activity } from './activity.entity';
import { Article } from './article.object';
import { URI } from './uri.object';
type ActorData = {
    username: string;
    displayName?: string;
    publicKey: string;
    privateKey: string;
    outbox: Activity[];
    inbox: Activity[];
    following: {
        id: URI;
        username?: string;
    }[];
    followers: {
        id: URI;
    }[];
};
type CreateActorData = ActorData & {
    id?: ObjectID;
};
export declare class Actor extends Entity<ActorData> {
    private getURI;
    get actorId(): URI;
    get publicKeyId(): URI;
    get inboxId(): URI;
    get outboxId(): URI;
    get followingCollectionId(): URI;
    get followersCollectionId(): URI;
    get featuredCollectionId(): URI;
    get username(): string;
    get displayName(): string;
    get inbox(): Activity[];
    get outbox(): Activity[];
    get following(): {
        id: URI;
        username?: string | undefined;
    }[];
    get followers(): {
        id: URI;
    }[];
    sign(request: Request, baseUrl: URL): Promise<Request>;
    readonly publicAccount = true;
    postToInbox(activity: Activity): Promise<void>;
    follow(actor: {
        id: URI;
        username: string;
    }): Promise<void>;
    acceptFollow(activity: Activity): Promise<void>;
    private doActivity;
    private activities;
    static getActivitiesToSave(actor: Actor, fn: (activities: Activity[]) => void): void;
    createArticle(article: Article): void;
    getJSONLD(url: URL): ActivityPub.Actor & ActivityPub.RootObject;
    static create(data: Partial<CreateActorData> & {
        username: string;
    }): Actor;
}
export {};
