"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Article = void 0;
const uri_object_1 = require("./uri.object");
class Article {
    attr;
    constructor(attr) {
        this.attr = attr;
    }
    get objectId() {
        return new uri_object_1.URI(`article/${this.attr.id.toHexString()}`);
    }
    getJSONLD(url) {
        if (!url.href.endsWith('/')) {
            url.href += '/';
        }
        const id = new URL(`article/${this.attr.id.toHexString()}`, url.href);
        return {
            '@context': 'https://www.w3.org/ns/activitystreams',
            type: 'Article',
            id: id.href,
            name: this.attr.name,
            content: this.attr.content,
            url: this.attr.url.getValue(url),
            image: this.attr.image?.getValue(url),
            published: this.attr.published?.toISOString(),
            attributedTo: this.attr.attributedTo,
            preview: this.attr.preview
        };
    }
    static fromPost(post) {
        return new Article({
            id: post.id,
            name: post.title,
            content: post.html,
            url: post.url,
            image: post.featuredImage,
            published: post.publishedAt,
            attributedTo: post.authors.map(name => ({
                type: 'Person',
                name
            })),
            preview: {
                type: 'Note',
                content: post.excerpt
            }
        });
    }
}
exports.Article = Article;
//# sourceMappingURL=article.object.js.map