"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const sinon_1 = __importDefault(require("sinon"));
const inbox_service_1 = require("./inbox.service");
const assert_1 = __importDefault(require("assert"));
const bson_objectid_1 = __importDefault(require("bson-objectid"));
const activity_entity_1 = require("./activity.entity");
const uri_object_1 = require("./uri.object");
const actor_entity_1 = require("./actor.entity");
describe('InboxService', function () {
    describe('#post', function () {
        it('Throws if it cannot find the actor', async function () {
            const mockActorRepository = {
                getOne: sinon_1.default.stub().resolves(null),
                save: sinon_1.default.stub().rejects()
            };
            const mockActivityRepository = {
                getOne: sinon_1.default.stub().resolves(null),
                save: sinon_1.default.stub().rejects()
            };
            const service = new inbox_service_1.InboxService(mockActorRepository, mockActivityRepository);
            const owner = new bson_objectid_1.default();
            const activity = new activity_entity_1.Activity({
                type: 'Follow',
                activity: null,
                object: {
                    type: 'Application',
                    id: new uri_object_1.URI('https://whatever.com')
                },
                actor: {
                    type: 'Person',
                    id: new uri_object_1.URI('https://blak.com')
                },
                to: new uri_object_1.URI('https://whatever.com')
            });
            await assert_1.default.rejects(async () => {
                await service.post(owner, activity);
            }, /Not Found/);
        });
        it('Posts the activity to the actors inbox, saves the actor & the activity', async function () {
            const actor = actor_entity_1.Actor.create({ username: 'username' });
            const mockActorRepository = {
                getOne: sinon_1.default.stub().resolves(actor),
                save: sinon_1.default.stub().resolves()
            };
            const mockActivityRepository = {
                getOne: sinon_1.default.stub().resolves(null),
                save: sinon_1.default.stub().resolves()
            };
            const service = new inbox_service_1.InboxService(mockActorRepository, mockActivityRepository);
            const postToInboxStub = sinon_1.default.stub(actor, 'postToInbox');
            const owner = new bson_objectid_1.default();
            const activity = new activity_entity_1.Activity({
                type: 'Follow',
                activity: null,
                object: {
                    type: 'Person',
                    id: new uri_object_1.URI('https://whatever.com')
                },
                actor: {
                    type: 'Person',
                    id: new uri_object_1.URI('https://blak.com')
                },
                to: new uri_object_1.URI('https://whatever.com')
            });
            await service.post(owner, activity);
            (0, assert_1.default)(postToInboxStub.calledWith(activity));
            (0, assert_1.default)(mockActorRepository.save.calledWith(actor));
            (0, assert_1.default)(mockActivityRepository.save.calledWith(activity));
        });
    });
});
//# sourceMappingURL=inbox.service.test.js.map