"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.JSONLDService = void 0;
const common_1 = require("@nestjs/common");
const article_object_1 = require("./article.object");
let JSONLDService = class JSONLDService {
    repository;
    postRepository;
    url;
    constructor(repository, postRepository, url) {
        this.repository = repository;
        this.postRepository = postRepository;
        this.url = url;
    }
    async getActor(id) {
        const actor = await this.repository.getOne(id);
        return actor?.getJSONLD(this.url);
    }
    async getFollowing(owner) {
        const actor = await this.repository.getOne(owner);
        if (!actor) {
            return null;
        }
        return {
            '@context': 'https://www.w3.org/ns/activitystreams',
            id: actor.followingCollectionId.getValue(this.url),
            summary: `Following collection for ${actor.username}`,
            type: 'Collection',
            totalItems: actor.following.length,
            items: actor.following.map(item => ({ id: item.id.getValue(this.url), username: item.username }))
        };
    }
    async getFollowers(owner) {
        const actor = await this.repository.getOne(owner);
        if (!actor) {
            return null;
        }
        return {
            '@context': 'https://www.w3.org/ns/activitystreams',
            id: actor.followersCollectionId.getValue(this.url),
            summary: `Followers collection for ${actor.username}`,
            type: 'Collection',
            totalItems: actor.followers.length,
            items: actor.followers.map(item => item.id.getValue(this.url))
        };
    }
    async getInbox(owner) {
        const actor = await this.repository.getOne(owner);
        if (!actor) {
            return null;
        }
        const json = actor.getJSONLD(this.url);
        return {
            '@context': 'https://www.w3.org/ns/activitystreams',
            id: json.inbox,
            summary: `Inbox for ${actor.username}`,
            type: 'OrderedCollection',
            totalItems: actor.inbox.length,
            orderedItems: actor.inbox.map(activity => activity.getJSONLD(this.url))
        };
    }
    async getOutbox(owner) {
        const actor = await this.repository.getOne(owner);
        if (!actor) {
            return null;
        }
        const json = actor.getJSONLD(this.url);
        return {
            '@context': 'https://www.w3.org/ns/activitystreams',
            id: json.outbox,
            summary: `Outbox for ${actor.username}`,
            type: 'OrderedCollection',
            totalItems: actor.outbox.length,
            orderedItems: actor.outbox.map(activity => activity.getJSONLD(this.url))
        };
    }
    async getArticle(id) {
        const post = await this.postRepository.getOne(id);
        if (!post) {
            throw new Error('Not found');
        }
        if (post.visibility !== 'public') {
            throw new Error('Cannot view');
        }
        return article_object_1.Article.fromPost(post).getJSONLD(this.url);
    }
};
exports.JSONLDService = JSONLDService;
exports.JSONLDService = JSONLDService = __decorate([
    __param(0, (0, common_1.Inject)('ActorRepository')),
    __param(1, (0, common_1.Inject)('PostRepository')),
    __param(2, (0, common_1.Inject)('ActivityPubBaseURL')),
    __metadata("design:paramtypes", [Object, Object, URL])
], JSONLDService);
//# sourceMappingURL=jsonld.service.js.map