"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TheWorld = void 0;
const common_1 = require("@nestjs/common");
let TheWorld = class TheWorld {
    url;
    logger;
    constructor(url, logger) {
        this.url = url;
        this.logger = logger;
    }
    async deliverActivity(activity, actor) {
        const recipients = await this.getRecipients(activity);
        for (const recipient of recipients) {
            const data = await this.fetchForActor(recipient.href, actor);
            if ('inbox' in data && typeof data.inbox === 'string') {
                const inbox = new URL(data.inbox);
                await this.sendActivity(inbox, activity, actor);
            }
            if ('type' in data && data.type === 'Collection') {
                if ('items' in data && Array.isArray(data.items)) {
                    for (const item of data.items) {
                        let url;
                        if (typeof item === 'string') {
                            url = new URL(item);
                        }
                        else if ('id' in item && typeof item.id === 'string') {
                            url = new URL(item.id);
                        }
                        if (url) {
                            const fetchedActor = await this.fetchForActor(url.href, actor);
                            if ('inbox' in fetchedActor && typeof fetchedActor.inbox === 'string') {
                                const inbox = new URL(fetchedActor.inbox);
                                await this.sendActivity(inbox, activity, actor);
                            }
                        }
                    }
                }
            }
        }
    }
    async sendActivity(to, activity, from) {
        const request = new Request(to.href, {
            method: 'POST',
            headers: {
                'Content-Type': 'application/ld+json'
            },
            body: JSON.stringify(activity.getJSONLD(this.url))
        });
        const signedRequest = await from.sign(request, this.url);
        try {
            await fetch(signedRequest);
        }
        catch (err) {
            this.logger.error(err);
        }
    }
    async getRecipients(activity) {
        const json = activity.getJSONLD(this.url);
        const recipients = [];
        if (json.to) {
            recipients.push(new URL(json.to));
        }
        return recipients;
    }
    async fetchForActor(uri, actor) {
        const request = new Request(uri, {
            headers: {
                Accept: 'application/ld+json'
            }
        });
        const signedRequest = await actor.sign(request, this.url);
        const result = await fetch(signedRequest);
        const json = await result.json();
        if (typeof json !== 'object' || json === null) {
            throw new Error('Could not read data');
        }
        return json;
    }
};
exports.TheWorld = TheWorld;
exports.TheWorld = TheWorld = __decorate([
    __param(0, (0, common_1.Inject)('ActivityPubBaseURL')),
    __param(1, (0, common_1.Inject)('logger')),
    __metadata("design:paramtypes", [URL, Object])
], TheWorld);
//# sourceMappingURL=tell-the-world.service.js.map