"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = __importDefault(require("assert"));
const activity_entity_1 = require("./activity.entity");
const actor_entity_1 = require("./actor.entity");
const tell_the_world_service_1 = require("./tell-the-world.service");
const uri_object_1 = require("./uri.object");
const nock_1 = __importDefault(require("nock"));
describe('TheWorld', function () {
    describe('deliverActivity', function () {
        beforeEach(function () {
            nock_1.default.disableNetConnect();
        });
        afterEach(function () {
            nock_1.default.enableNetConnect();
        });
        it('Can deliver the activity to the inbox of the desired recipient', async function () {
            const service = new tell_the_world_service_1.TheWorld(new URL('https://base.com'), console);
            const actor = actor_entity_1.Actor.create({
                username: 'Testing'
            });
            const toFollow = new uri_object_1.URI('https://main.ghost.org/activitypub/actor/deadbeefdeadbeefdeadbeef');
            const activity = new activity_entity_1.Activity({
                type: 'Follow',
                activity: null,
                actor: actor,
                object: {
                    type: 'Person',
                    id: toFollow
                },
                to: toFollow
            });
            const actorFetch = (0, nock_1.default)('https://main.ghost.org')
                .get('/activitypub/actor/deadbeefdeadbeefdeadbeef')
                .reply(200, {
                inbox: 'https://main.ghost.org/activitypub/inbox/deadbeefdeadbeefdeadbeef'
            });
            const activityDelivery = (0, nock_1.default)('https://main.ghost.org')
                .post('/activitypub/inbox/deadbeefdeadbeefdeadbeef')
                .reply(201, {});
            await service.deliverActivity(activity, actor);
            (0, assert_1.default)(actorFetch.isDone(), 'Expected actor to be fetched');
            (0, assert_1.default)(activityDelivery.isDone(), 'Expected activity to be delivered');
        });
        it('Can deliver the activity to the inboxes of a collection of actors', async function () {
            const service = new tell_the_world_service_1.TheWorld(new URL('https://base.com'), console);
            const actor = actor_entity_1.Actor.create({
                username: 'Testing'
            });
            const followers = new uri_object_1.URI('https://main.ghost.org/activitypub/followers/deadbeefdeadbeefdeadbeef');
            const activity = new activity_entity_1.Activity({
                type: 'Create',
                activity: null,
                actor: actor,
                object: {
                    id: new uri_object_1.URI('https://main.ghost.org/hello-world'),
                    type: 'Note',
                    content: '<p> Hello, world. </p>'
                },
                to: followers
            });
            (0, nock_1.default)('https://main.ghost.org')
                .get('/activitypub/followers/deadbeefdeadbeefdeadbeef')
                .reply(200, {
                '@context': '',
                type: 'Collection',
                totalItems: 3,
                items: [
                    'https://main.ghost.org/activitypub/actor/deadbeefdeadbeefdeadbeef',
                    {
                        id: 'https://main.ghost.org/activitypub/actor/beefdeadbeefdeadbeefdead'
                    },
                    {
                        invalid: true
                    }
                ]
            });
            (0, nock_1.default)('https://main.ghost.org')
                .get('/activitypub/actor/deadbeefdeadbeefdeadbeef')
                .reply(200, {
                inbox: 'https://main.ghost.org/activitypub/inbox/deadbeefdeadbeefdeadbeef'
            });
            (0, nock_1.default)('https://main.ghost.org')
                .get('/activitypub/actor/beefdeadbeefdeadbeefdead')
                .reply(200, {
                inbox: 'https://main.ghost.org/activitypub/inbox/beefdeadbeefdeadbeefdead'
            });
            const firstActivityDelivery = (0, nock_1.default)('https://main.ghost.org')
                .post('/activitypub/inbox/deadbeefdeadbeefdeadbeef')
                .reply(201, {});
            const secondActivityDelivery = (0, nock_1.default)('https://main.ghost.org')
                .post('/activitypub/inbox/beefdeadbeefdeadbeefdead')
                .reply(201, {});
            await service.deliverActivity(activity, actor);
            (0, assert_1.default)(firstActivityDelivery.isDone(), 'Expected activity to be delivered');
            (0, assert_1.default)(secondActivityDelivery.isDone(), 'Expected activity to be delivered');
        });
    });
});
//# sourceMappingURL=tell-the-world.service.test.js.map