export declare namespace ActivityPub {
    type AnonymousObject = {
        '@context': string | (string | object)[];
        id: null;
        type: string | string[];
    };
    type RootObject = {
        '@context': string | (string | object)[];
        id: string;
        type: string | string[];
    };
    type SubObject = {
        id: string;
        type: string | string[];
    };
    type Object = RootObject | AnonymousObject | SubObject;
    type Actor = ActivityPub.Object & {
        inbox: string;
        outbox: string;
        name: string;
        preferredUsername: string;
        summary: string;
        url: string;
        icon: string;
        image: string;
        published: string;
        manuallyApprovesFollowers: boolean;
        discoverable: boolean;
        attachment: object[];
        following: string;
        followers: string;
        featured: string;
        publicKey: {
            id: string;
            owner: string;
            publicKeyPem: string;
        };
        [x: string]: any;
    };
    type Article = ActivityPub.Object & {
        type: 'Article';
        name: string;
        content: string;
        url?: string;
        attributedTo?: string | object[];
        image?: string;
        published?: string;
        preview?: {
            type: string;
            content: string;
        };
    };
    type Link = string | {
        type: 'Link';
        href: string;
        id?: string;
        hreflang?: string;
        mediaType?: string;
        rel?: string;
        height?: number;
        width?: number;
    };
    type ActivityType = 'Create' | 'Update' | 'Delete' | 'Follow' | 'Accept' | 'Reject' | 'Undo';
    type Activity = ActivityPub.Object & {
        type: ActivityType;
        actor: Link | Actor | ActivityPub.Object;
        object: Link | ActivityPub.Object;
        to: Link | Actor | null;
    };
}
