"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = __importDefault(require("assert"));
const webfinger_service_1 = require("./webfinger.service");
const actor_entity_1 = require("./actor.entity");
describe('WebFingerService', function () {
    describe('getResource', function () {
        it('Throws with invalid resource', async function () {
            const repository = {};
            const service = new webfinger_service_1.WebFingerService(repository, new URL('https://activitypub.server'));
            await service.getResource('invalid').then(() => {
                throw new Error('Should have thrown');
            }, (err) => {
                assert_1.default.ok(err);
            });
        });
        it('Throws with missing actor', async function () {
            const repository = {
                async getOne() {
                    return null;
                }
            };
            const service = new webfinger_service_1.WebFingerService(repository, new URL('https://activitypub.server'));
            await service.getResource('invalid').then(() => {
                throw new Error('Should have thrown');
            }, (err) => {
                assert_1.default.ok(err);
            });
        });
        it('Responds with webfinger for found actors', async function () {
            const actor = actor_entity_1.Actor.create({ username: 'c00ld00d' });
            const repository = {
                async getOne() {
                    return actor;
                }
            };
            const url = new URL('https://activitypub.server');
            const service = new webfinger_service_1.WebFingerService(repository, url);
            const subject = 'acct:c00ld00d@activitypub.server';
            const result = await service.getResource(subject);
            assert_1.default.deepEqual(result, {
                subject,
                links: [{
                        rel: 'self',
                        type: 'application/activity+json',
                        href: actor.getJSONLD(url).id
                    }]
            });
        });
    });
    describe('#finger', function () {
        it('Throws with invalid usernames', async function () {
            const repository = {};
            const service = new webfinger_service_1.WebFingerService(repository, new URL('https://activitypub.server'));
            await service.finger('invalid').then(() => {
                throw new Error('Should have thrown');
            }, (err) => {
                assert_1.default.ok(err);
            });
        });
    });
});
//# sourceMappingURL=webfinger.service.test.js.map