"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.KnexPostRepository = void 0;
const common_1 = require("@nestjs/common");
const uri_object_1 = require("../../core/activitypub/uri.object");
const html_to_plaintext_1 = __importDefault(require("@tryghost/html-to-plaintext"));
let KnexPostRepository = class KnexPostRepository {
    knex;
    urlUtils;
    constructor(knex, urlUtils) {
        this.knex = knex;
        this.urlUtils = urlUtils;
    }
    async getOne(identifier) {
        return this.getOneById(identifier);
    }
    async getOneById(id) {
        const row = await this.knex('posts').where('id', id.toHexString()).first();
        const authorRows = await this.knex('users')
            .leftJoin('posts_authors', 'users.id', 'posts_authors.author_id')
            .where('posts_authors.post_id', id.toHexString())
            .select('users.name');
        if (!row) {
            return null;
        }
        let excerpt = row.custom_excerpt;
        if (!excerpt) {
            const metaRow = await this.knex('posts_meta').where('post_id', id.toHexString()).select('meta_description').first();
            if (metaRow?.meta_description) {
                excerpt = metaRow.meta_description;
            }
        }
        if (!excerpt) {
            excerpt = html_to_plaintext_1.default.excerpt(row.html);
        }
        return {
            id,
            title: row.title,
            html: this.urlUtils.transformReadyToAbsolute(row.html),
            slug: row.slug,
            visibility: row.visibility,
            featuredImage: row.feature_image ? new uri_object_1.URI(row.feature_image) : null,
            publishedAt: row.published_at ? new Date(row.published_at) : null,
            authors: authorRows.map((authorRow) => authorRow.name),
            excerpt,
            url: new uri_object_1.URI('') // TODO: Get URL for Post
        };
    }
};
exports.KnexPostRepository = KnexPostRepository;
exports.KnexPostRepository = KnexPostRepository = __decorate([
    __param(0, (0, common_1.Inject)('knex')),
    __param(1, (0, common_1.Inject)('UrlUtils')),
    __metadata("design:paramtypes", [Object, Object])
], KnexPostRepository);
;
//# sourceMappingURL=post.repository.knex.js.map