"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ActivityPubController = void 0;
const common_1 = require("@nestjs/common");
const permissions_decorator_1 = require("../../../common/decorators/permissions.decorator");
const bson_objectid_1 = __importDefault(require("bson-objectid"));
const jsonld_service_1 = require("../../../core/activitypub/jsonld.service");
const http_signature_service_1 = require("../../../core/activitypub/http-signature.service");
const inbox_service_1 = require("../../../core/activitypub/inbox.service");
const activity_entity_1 = require("../../../core/activitypub/activity.entity");
let ActivityPubController = class ActivityPubController {
    service;
    inboxService;
    constructor(service, inboxService) {
        this.service = service;
        this.inboxService = inboxService;
    }
    async getActor(id) {
        if (typeof id !== 'string') {
            throw new Error('Bad Request');
        }
        return this.service.getActor(bson_objectid_1.default.createFromHexString(id));
    }
    async getInbox(owner) {
        if (typeof owner !== 'string') {
            throw new Error('Bad Request');
        }
        return this.service.getInbox(bson_objectid_1.default.createFromHexString(owner));
    }
    async handleActivity(owner, body, rawbody, headers, req) {
        if (typeof owner !== 'string') {
            throw new Error('Bad Request');
        }
        if (typeof body !== 'object' || body === null) {
            throw new Error('Bad Request');
        }
        if (!('id' in body) || !('type' in body) || !('actor' in body) || !('object' in body)) {
            throw new Error('Bad Request');
        }
        const verified = await http_signature_service_1.HTTPSignature.validate(req.method, req.url, new Headers(headers), rawbody);
        if (!verified) {
            throw new Error('Not Authorized');
        }
        this.inboxService.post(bson_objectid_1.default.createFromHexString(owner), activity_entity_1.Activity.fromJSONLD(body));
    }
    async getOutbox(owner) {
        if (typeof owner !== 'string') {
            throw new Error('Bad Request');
        }
        return this.service.getOutbox(bson_objectid_1.default.createFromHexString(owner));
    }
    async getFollowing(owner) {
        if (typeof owner !== 'string') {
            throw new Error('Bad Request');
        }
        return this.service.getFollowing(bson_objectid_1.default.createFromHexString(owner));
    }
    async getFollowers(owner) {
        if (typeof owner !== 'string') {
            throw new Error('Bad Request');
        }
        return this.service.getFollowers(bson_objectid_1.default.createFromHexString(owner));
    }
    async getArticle(id) {
        if (typeof id !== 'string') {
            throw new Error('Bad Request');
        }
        return this.service.getArticle(bson_objectid_1.default.createFromHexString(id));
    }
};
exports.ActivityPubController = ActivityPubController;
__decorate([
    (0, common_1.Header)('Cache-Control', 'no-store'),
    (0, common_1.Header)('Content-Type', 'application/activity+json'),
    (0, permissions_decorator_1.Roles)(['Anon']),
    (0, common_1.Get)('actor/:id'),
    __param(0, (0, common_1.Param)('id')),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", Promise)
], ActivityPubController.prototype, "getActor", null);
__decorate([
    (0, common_1.Header)('Cache-Control', 'no-store'),
    (0, common_1.Header)('Content-Type', 'application/activity+json'),
    (0, permissions_decorator_1.Roles)(['Anon']),
    (0, common_1.Get)('inbox/:owner'),
    __param(0, (0, common_1.Param)('owner')),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", Promise)
], ActivityPubController.prototype, "getInbox", null);
__decorate([
    (0, common_1.Header)('Cache-Control', 'no-store'),
    (0, common_1.Header)('Content-Type', 'application/activity+json'),
    (0, permissions_decorator_1.Roles)(['Anon']),
    (0, common_1.Post)('inbox/:owner'),
    __param(0, (0, common_1.Param)('owner')),
    __param(1, (0, common_1.Body)()),
    __param(2, (0, common_1.RawBody)()),
    __param(3, (0, common_1.Headers)()),
    __param(4, (0, common_1.Req)()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, Buffer, Object, Request]),
    __metadata("design:returntype", Promise)
], ActivityPubController.prototype, "handleActivity", null);
__decorate([
    (0, common_1.Header)('Cache-Control', 'no-store'),
    (0, common_1.Header)('Content-Type', 'application/activity+json'),
    (0, permissions_decorator_1.Roles)(['Anon']),
    (0, common_1.Get)('outbox/:owner'),
    __param(0, (0, common_1.Param)('owner')),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", Promise)
], ActivityPubController.prototype, "getOutbox", null);
__decorate([
    (0, common_1.Header)('Cache-Control', 'no-store'),
    (0, common_1.Header)('Content-Type', 'application/activity+json'),
    (0, permissions_decorator_1.Roles)(['Anon']),
    (0, common_1.Get)('following/:owner'),
    __param(0, (0, common_1.Param)('owner')),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", Promise)
], ActivityPubController.prototype, "getFollowing", null);
__decorate([
    (0, common_1.Header)('Cache-Control', 'no-store'),
    (0, common_1.Header)('Content-Type', 'application/activity+json'),
    (0, permissions_decorator_1.Roles)(['Anon']),
    (0, common_1.Get)('followers/:owner'),
    __param(0, (0, common_1.Param)('owner')),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", Promise)
], ActivityPubController.prototype, "getFollowers", null);
__decorate([
    (0, common_1.Header)('Cache-Control', 'no-store'),
    (0, common_1.Header)('Content-Type', 'application/activity+json'),
    (0, permissions_decorator_1.Roles)(['Anon']),
    (0, common_1.Get)('article/:id'),
    __param(0, (0, common_1.Param)('id')),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", Promise)
], ActivityPubController.prototype, "getArticle", null);
exports.ActivityPubController = ActivityPubController = __decorate([
    (0, common_1.Controller)('activitypub'),
    __metadata("design:paramtypes", [jsonld_service_1.JSONLDService,
        inbox_service_1.InboxService])
], ActivityPubController);
//# sourceMappingURL=activitypub.controller.js.map