"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const supertest_1 = __importDefault(require("supertest"));
const testing_1 = require("@nestjs/testing");
const webfinger_service_1 = require("../../../core/activitypub/webfinger.service");
const activity_repository_in_memory_1 = require("../../../db/in-memory/activity.repository.in-memory");
const activitypub_controller_1 = require("./activitypub.controller");
const jsonld_service_1 = require("../../../core/activitypub/jsonld.service");
const inbox_service_1 = require("../../../core/activitypub/inbox.service");
const activitypub_service_1 = require("../../../core/activitypub/activitypub.service");
const actor_repository_in_memory_1 = require("../../../db/in-memory/actor.repository.in-memory");
const activity_service_1 = require("../../../core/activitypub/activity.service");
const http_signature_service_1 = require("../../../core/activitypub/http-signature.service");
const activity_listener_1 = require("../../../listeners/activity.listener");
const tell_the_world_service_1 = require("../../../core/activitypub/tell-the-world.service");
const domain_events_1 = __importDefault(require("@tryghost/domain-events"));
const uri_object_1 = require("../../../core/activitypub/uri.object");
describe('ActivityPubController', function () {
    let app;
    before(async function () {
        const moduleRef = await testing_1.Test.createTestingModule({
            controllers: [activitypub_controller_1.ActivityPubController],
            providers: [
                {
                    provide: 'logger',
                    useValue: console
                },
                {
                    provide: 'ActivityPubBaseURL',
                    useValue: new URL('https://example.com')
                },
                {
                    provide: 'SettingsCache',
                    useValue: {
                        get(_key) {
                            return 'value';
                        }
                    }
                },
                {
                    provide: 'DomainEvents',
                    useValue: domain_events_1.default
                },
                {
                    provide: 'ActorRepository',
                    useClass: actor_repository_in_memory_1.ActorRepositoryInMemory
                },
                {
                    provide: 'ActivityService',
                    useClass: activity_service_1.ActivityService
                },
                {
                    provide: 'PostRepository',
                    useValue: {
                        async getOne(id) {
                            return {
                                id,
                                title: 'Testing',
                                slug: 'testing',
                                html: '<p> testing </p>',
                                visibility: 'public',
                                authors: ['Mr Roach'],
                                url: new uri_object_1.URI('roachie'),
                                publishedAt: new Date(),
                                featuredImage: null,
                                excerpt: 'testing...'
                            };
                        }
                    }
                },
                {
                    provide: 'ActivityRepository',
                    useClass: activity_repository_in_memory_1.ActivityRepositoryInMemory
                },
                webfinger_service_1.WebFingerService,
                jsonld_service_1.JSONLDService,
                http_signature_service_1.HTTPSignature,
                activity_service_1.ActivityService,
                inbox_service_1.InboxService,
                activity_listener_1.ActivityListener,
                activitypub_service_1.ActivityPubService,
                tell_the_world_service_1.TheWorld
            ]
        }).compile();
        app = moduleRef.createNestApplication();
        await app.init();
    });
    after(async function () {
        await app.close();
    });
    it('Can handle requests to get the actor', async function () {
        await (0, supertest_1.default)(app.getHttpServer())
            .get('/activitypub/actor/deadbeefdeadbeefdeadbeef')
            .expect(200);
    });
    it('Can handle requests to get the outbox', async function () {
        await (0, supertest_1.default)(app.getHttpServer())
            .get('/activitypub/outbox/deadbeefdeadbeefdeadbeef')
            .expect(200);
    });
    it('Can handle requests to get the inbox', async function () {
        await (0, supertest_1.default)(app.getHttpServer())
            .get('/activitypub/inbox/deadbeefdeadbeefdeadbeef')
            .expect(200);
    });
    it('Can handle requests to get the following', async function () {
        await (0, supertest_1.default)(app.getHttpServer())
            .get('/activitypub/following/deadbeefdeadbeefdeadbeef')
            .expect(200);
    });
    it('Can handle requests to get the followers', async function () {
        await (0, supertest_1.default)(app.getHttpServer())
            .get('/activitypub/followers/deadbeefdeadbeefdeadbeef')
            .expect(200);
    });
    it('Can handle requests to get an article', async function () {
        await (0, supertest_1.default)(app.getHttpServer())
            .get('/activitypub/article/deadbeefdeadbeefdeadbeef')
            .expect(200);
    });
    describe('/inbox/:id', function () {
        it('Errors with invalid requests', async function () {
            await (0, supertest_1.default)(app.getHttpServer())
                .post('/activitypub/inbox/deadbeefdeadbeefdeadbeef')
                .send({
                type: 'Follow',
                actor: 'https://site.com/actor',
                object: 'https://site.com/object'
            })
                .expect(500);
        });
    });
});
//# sourceMappingURL=activitypub.controller.test.js.map