"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const supertest_1 = __importDefault(require("supertest"));
const testing_1 = require("@nestjs/testing");
const webfinger_service_1 = require("../../../core/activitypub/webfinger.service");
const webfinger_controller_1 = require("./webfinger.controller");
const activity_repository_in_memory_1 = require("../../../db/in-memory/activity.repository.in-memory");
describe('WebFingerController', function () {
    it('Responds to HTTP requests for .well-known/webfinger correctly', async function () {
        const moduleRef = await testing_1.Test.createTestingModule({
            controllers: [webfinger_controller_1.WebFingerController],
            providers: [
                webfinger_service_1.WebFingerService,
                {
                    provide: 'ActivityPubBaseURL',
                    useValue: new URL('https://example.com')
                },
                {
                    provide: 'ActorRepository',
                    useClass: activity_repository_in_memory_1.ActivityRepositoryInMemory
                }
            ]
        })
            .overrideProvider(webfinger_service_1.WebFingerService)
            .useValue({
            async getResource() { }
        })
            .compile();
        const app = moduleRef.createNestApplication();
        await app.init();
        (0, supertest_1.default)(app.getHttpServer())
            .get('/.well-known/webfinger?resource=acct:egg@ghost.org')
            .expect(200);
        await app.close();
    });
});
//# sourceMappingURL=webfinger.controller.test.js.map