"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = __importDefault(require("assert"));
const activity_entity_1 = require("../core/activitypub/activity.entity");
const activity_event_1 = require("../core/activitypub/activity.event");
const actor_entity_1 = require("../core/activitypub/actor.entity");
const tell_the_world_service_1 = require("../core/activitypub/tell-the-world.service");
const uri_object_1 = require("../core/activitypub/uri.object");
const activity_listener_1 = require("./activity.listener");
describe('ActivityListener', function () {
    describe('#dispatchActivity', function () {
        it('uses the service to deliver the activity', function () {
            let called = false;
            const calledWith = [];
            class MockTheWorld extends tell_the_world_service_1.TheWorld {
                async deliverActivity(activity, actor) {
                    called = true;
                    calledWith.push([activity, actor]);
                }
            }
            const listener = new activity_listener_1.ActivityListener(new MockTheWorld(new URL('https://example.com'), console));
            const actor = actor_entity_1.Actor.create({
                username: 'Testing'
            });
            const toFollow = new uri_object_1.URI('https://example.com/user');
            const activity = new activity_entity_1.Activity({
                type: 'Follow',
                activity: null,
                actor: actor,
                object: {
                    type: 'Person',
                    id: toFollow
                },
                to: toFollow
            });
            const event = new activity_event_1.ActivityEvent({
                activity,
                actor
            });
            listener.dispatchActivity(event);
            assert_1.default.equal(called, true);
            assert_1.default.equal(calledWith[0][0], activity);
            assert_1.default.equal(calledWith[0][1], actor);
        });
    });
});
//# sourceMappingURL=activity.listener.test.js.map